.. _user-tutorial:

########
Tutorial
########

.. note::

          This is a new section in the django CMS documentation, and a priority
          for the project. If you'd like to contribute to it, we'd love to hear
          from you - join us on `our friendly Slack group
          <https://www.django-cms.org/slack>`_.

It's strongly recommended that you follow this tutorial step-by-step. It has
been designed to introduce you to the system in a methodical way, and each
step builds on the previous one.

.. toctree::
    :maxdepth: 2

    log-in
    create_page
    page_settings
    structure-content-modes

.. note:: **Touch-screen users**

    django CMS supports touch-screen interfaces, though there are currently some limitations in
    support. You will be able to complete the tutorial using a touch-screen device, but please
    consult :ref:`touch`, and see the notes on :ref:`device-support`.

.. _django-cms-developers: https://groups.google.com/group/django-cms-developers
.. _freenode : http://freenode.net/
